@@ -338,12 +338,15 @@ class IntelliFireAPICloud(IntelliFireController, IntelliFireDataProvider):
             self._should_poll_in_background = True
             _log.info("!! CLOUD::start_background_polling !!")
 
-        self._bg_task = asyncio.create_task(
-            self.__background_poll(minimum_wait_in_seconds=minimum_wait_in_seconds),
-            name="background_cloud_polling",
-        )
+            # Do an initial poll to set data first
+            await self.poll()
 
-    def stop_background_polling(self) -> bool:
+            self._bg_task = asyncio.create_task(
+                self.__background_poll(minimum_wait_in_seconds=minimum_wait_in_seconds),
+                name="background_cloud_polling",
+            )
+
+    async def stop_background_polling(self) -> bool:
         """Stop background polling - return whether it had been polling."""
         self._should_poll_in_background = False
         was_running = False
